@@ -45,7 +45,7 @@
 #include <Eigen/Core>
 #include <Eigen/Geometry>
 // import most common Eigen types
-USING_PART_OF_NAMESPACE_EIGEN
+using namespace Eigen;
 
 // the screen saver preview area class
 #include "sspreviewarea.h"
