@@ -182,16 +182,16 @@ void kSlideShowSaver::registerEffects()
   int i = 0;
 
   mEffectList = new EffectMethod[64];
-  mEffectList[i++] = &kSlideShowSaver::effectChessboard;
+//  mEffectList[i++] = &kSlideShowSaver::effectChessboard;
   mEffectList[i++] = &kSlideShowSaver::effectMultiCircleOut;
   mEffectList[i++] = &kSlideShowSaver::effectSpiralIn;
   mEffectList[i++] = &kSlideShowSaver::effectSweep;
-  mEffectList[i++] = &kSlideShowSaver::effectMeltdown;
+//  mEffectList[i++] = &kSlideShowSaver::effectMeltdown;
   mEffectList[i++] = &kSlideShowSaver::effectCircleOut;
   mEffectList[i++] = &kSlideShowSaver::effectBlobs;
-  mEffectList[i++] = &kSlideShowSaver::effectHorizLines;
-  mEffectList[i++] = &kSlideShowSaver::effectVertLines;
-  mEffectList[i++] = &kSlideShowSaver::effectRandom;
+//  mEffectList[i++] = &kSlideShowSaver::effectHorizLines;
+//  mEffectList[i++] = &kSlideShowSaver::effectVertLines;
+//  mEffectList[i++] = &kSlideShowSaver::effectRandom;
   mEffectList[i++] = &kSlideShowSaver::effectGrowing;
   mEffectList[i++] = &kSlideShowSaver::effectIncomingEdges;
 
@@ -481,9 +481,9 @@ int kSlideShowSaver::effectBlobs(bool aInit)
     return -1;
   }
 
-  mx = KRandom::random() % mw;
-  my = KRandom::random() % mh;
-  r = (KRandom::random() % 200) + 50;
+  r = (KRandom::random() % 100) + 100;
+  mx = KRandom::random() % (mw + r);
+  my = KRandom::random() % (mh + r);
 
   QBrush brush;
   brush.setTexture(mNextScreen);
